<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              optimum7.com
 * @since             1.0.0
 * @package           Ffl_Api
 *
 * @wordpress-plugin
 * Plugin Name:       FFl API
 * Plugin URI:        fflapi.com
 * Description:       FFL API Woocommerce plugin
 * Version:           1.5.9
 * WC requires at least: 3.0.0
 * WC tested up to:   6.1.1
 * Author:            Optimum7
 * Author URI:        optimum7.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       ffl-api
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

if ( ! defined('ABSPATH')) exit;  // if direct access


/**
 * Check if WooCommerce is active
 **/
if (! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
    die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define('FFL_API_VERSION', '1.5.9');

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-ffl-api-activator.php
 */
function activate_ffl_api()
{
    require_once plugin_dir_path(__FILE__) . 'includes/class-ffl-api-activator.php';
    Ffl_Api_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-ffl-api-deactivator.php
 */
function deactivate_ffl_api()
{
    require_once plugin_dir_path(__FILE__) . 'includes/class-ffl-api-deactivator.php';
    Ffl_Api_Deactivator::deactivate();
}

register_activation_hook(__FILE__, 'activate_ffl_api');
register_deactivation_hook(__FILE__, 'deactivate_ffl_api');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path(__FILE__) . 'includes/class-ffl-api.php';
require plugin_dir_path(__FILE__) . 'plugin-update-checker/plugin-update-checker.php';

$myUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
    'https://wp-plugin-update.opt7dev.com/?action=get_metadata&slug=ffl_woocommerce_plugin',
    __FILE__, //Full path to the main plugin file or functions.php.
    'ffl_woocommerce_plugin'
);

require_once plugin_dir_path(__FILE__) . 'wp-dynamic-css/bootstrap.php';

// Enqueue the stylesheet (using an absolute path, not a URL)
wp_dynamic_css_enqueue('ffl_dynamic_style', plugin_dir_path(__FILE__) . 'public/css/ffl-api-public.css');

function ffl_dynamic_css_callback($var_name)
{

    $ffl_theme_defaults = array(
        'ffl_list_text_option' => '#fff',
        'ffl_list_background_option' => '#7eb8f9',
    );

//    return get_theme_mod($var_name, @$ffl_theme_defaults[$var_name]);
    return get_option($var_name, @$ffl_theme_defaults[$var_name]);
}

wp_dynamic_css_set_callback('ffl_dynamic_style', 'ffl_dynamic_css_callback');

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_ffl_api()
{

    $plugin = new Ffl_Api();
    $plugin->run();

}

run_ffl_api();
